@@ -1,5 +1,5 @@
 package Catan::Game;
-$Catan::Game::VERSION = '0.02';
+$Catan::Game::VERSION = '0.03';
 use strict;
 use 5.20.0;
 use experimental qw/postderef signatures/;
@@ -31,22 +31,14 @@ our %actions = (
   CH => \&chat,
   CR => \&concede_resources,
   DR => \&dice_roll,
-  GO => \&game_over,
-  LA => \&largest_army,
-  LR => \&longest_road,
   MD => \&map_define,
   MO => \&monopoly,
   PA => \&player_add,
   PD => \&play_dc,
   PE => \&phase_end,
-  PS => \&phase_start,
-  RA => \&robber_activate,
-  RD => \&robber_deactivate,
-  RE => \&round_end,
   RM => \&robber_move,
   RP => \&resource_production,
   RR => \&robber_rob,
-  RS => \&round_start,
   TA => \&trade_accept,
   TB => \&trade_bank,
   TC => \&trade_cancel,
@@ -54,6 +46,15 @@ our %actions = (
   TO => \&trade_offer,
   TS => \&turn_start,
   YP => \&year_of_plenty,
+# these are called automatically:
+#  GO => \&game_over,
+#  LA => \&largest_army,
+#  LR => \&longest_road,
+#  PS => \&phase_start,
+#  RA => \&robber_activate,
+#  RD => \&robber_deactivate,
+#  RE => \&round_end,
+#  RS => \&round_start,
 );
 
 sub new ($class, $args = {})
@@ -75,7 +76,7 @@ sub new ($class, $args = {})
   }, $class;
 
   # begin setup phase (and print to log if present)
-  $self->action('PS', {phase => 'setup'});
+  $self->_log($self->phase_start);
 
   return $self;
 }
@@ -569,6 +570,27 @@ sub robber_move ($self, $args)
 
 sub phase_end ($self, $args = {})
 {
+  # check a map is defined, and there are 3+ players
+  if ($self->phase eq 'Setup')
+  {
+    die "The Setup phase cannot end until a map has been defined (MD)\n"
+      unless defined $self->map;
+
+    die "The Setup phase cannot end until there are at least 3 players\n"
+      unless @{$self->players} >= 3;
+  }
+  elsif ($self->phase eq 'Deployment')
+  {
+    my $player = $self->player;
+    die "The Deployment phase cannot end until all players have gone $player\n"
+      unless $self->round == 2 && $self->player->number eq "1";
+  }
+  elsif ($self->phase eq 'Play')
+  {
+    die "The Play phase cannot end until a player has won the game\n"
+      unless defined $self->player_victory_check;
+  }
+
   return [ { PE => {phase => $self->phase} }, @{$self->phase_start} ];
 }
 
@@ -931,7 +953,7 @@ Catan::Game - a class for managing games of Catan
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
